@@ -2,8 +2,9 @@
 """
 # pylint: disable=R0917
 import logging
-import platform
+import sys
 import time
+from io import TextIOWrapper
 
 from typing import List, Optional
 
@@ -12,9 +13,7 @@ import serial # type: ignore[import-untyped]
 import meshtastic.util
 from meshtastic.stream_interface import StreamInterface
 
-if platform.system() != "Windows":
-    import termios
-
+logger = logging.getLogger(__name__)
 
 class SerialInterface(StreamInterface):
     """Interface class for meshtastic devices over a serial link"""
@@ -33,7 +32,7 @@ class SerialInterface(StreamInterface):
 
         if self.devPath is None:
             ports: List[str] = meshtastic.util.findPorts(True)
-            logging.debug(f"ports:{ports}")
+            logger.debug(f"ports:{ports}")
             if len(ports) == 0:
                 print("No Serial Meshtastic device detected, attempting TCP connection on localhost.")
                 return
@@ -44,16 +43,11 @@ class SerialInterface(StreamInterface):
             else:
                 self.devPath = ports[0]
 
-        logging.debug(f"Connecting to {self.devPath}")
+        logger.debug(f"Connecting to {self.devPath}")
 
-        # first we need to set the HUPCL so the device will not reboot based on RTS and/or DTR
-        # see https://github.com/pyserial/pyserial/issues/124
-        if platform.system() != "Windows":
+        if sys.platform != "win32":
             with open(self.devPath, encoding="utf8") as f:
-                attrs = termios.tcgetattr(f)
-                attrs[2] = attrs[2] & ~termios.HUPCL
-                termios.tcsetattr(f, termios.TCSAFLUSH, attrs)
-                f.close()
+                self._set_hupcl_with_termios(f)
             time.sleep(0.1)
 
         self.stream = serial.Serial(
@@ -66,6 +60,18 @@ class SerialInterface(StreamInterface):
             self, debugOut=debugOut, noProto=noProto, connectNow=connectNow, noNodes=noNodes
         )
 
+    def _set_hupcl_with_termios(self, f: TextIOWrapper):
+        """first we need to set the HUPCL so the device will not reboot based on RTS and/or DTR
+        see https://github.com/pyserial/pyserial/issues/124
+        """
+        if sys.platform == "win32":
+            return
+
+        import termios  # pylint: disable=C0415,E0401
+        attrs = termios.tcgetattr(f)
+        attrs[2] = attrs[2] & ~termios.HUPCL
+        termios.tcsetattr(f, termios.TCSAFLUSH, attrs)
+
     def __repr__(self):
         rep = f"SerialInterface(devPath={self.devPath!r}"
         if hasattr(self, 'debugOut') and self.debugOut is not None:
@@ -84,5 +90,5 @@ class SerialInterface(StreamInterface):
             time.sleep(0.1)
             self.stream.flush()
             time.sleep(0.1)
-        logging.debug("Closing Serial stream")
+        logger.debug("Closing Serial stream")
         StreamInterface.close(self)
